@@ -71,10 +71,18 @@ class AppSettings(object):
     def APIGATEWAY_CONSUMER_GROUPS_HEADER(self):
         return self._setting('APIGATEWAY_CONSUMER_GROUPS_HEADER', 'HTTP_X_CONSUMER_GROUPS')
 
+    @property
+    def APIGATEWAY_ANONYMOUS_CONSUMER_IDS(self):
+        return self._setting('APIGATEWAY_ANONYMOUS_CONSUMER_IDS', ['anonymous'], list)
+
     @property
     def APIGATEWAY_ANONYMOUS_CONSUMER_HEADER(self):
         return self._setting('APIGATEWAY_ANONYMOUS_CONSUMER_HEADER', 'HTTP_X_ANONYMOUS_CONSUMER')
 
+    @property
+    def APIGATEWAY_ANONYMOUS_CONSUMER_HEADER_VALUE(self):
+        return self._setting('APIGATEWAY_ANONYMOUS_CONSUMER_HEADER_VALUE', 'true')
+
     @property
     def BACKEND_STANDALONE(self):
         return self.SHAPE.find('standalone') > -1
