@@ -10,7 +10,7 @@ def get_apigateway_profile_groups_from_header(groups_header: str) -> list:
     :param groups_header:
     :return:
     """
-    if groups_header not in [None, '']:
+    if groups_header not in (None, ''):
         return list(map(str.strip, groups_header.split(',')))
 
     return []
