@@ -5,8 +5,8 @@ from .views import GroupApiViewSet
 
 
 urlpatterns = [
-    url(r'^$', GroupApiViewSet.as_view({'get': 'list'}), name="list"),
-    url(r'^(?P<pk>\w+)/$', GroupApiViewSet.as_view({'get': 'retrieve'}), name="detail"),
+    url(r'^$', GroupApiViewSet.as_view({'get': 'list'}), name="rest-list"),
+    url(r'^(?P<pk>\w+)/$', GroupApiViewSet.as_view({'get': 'retrieve'}), name="rest-detail"),
 ]
 
 urlpatterns = (format_suffix_patterns(urlpatterns), 'django_sso_app_group')
