@@ -2,6 +2,7 @@ import logging
 
 from django.db import models
 from django.utils.translation import ugettext_lazy as _
+from django.utils import timezone
 from django.urls import reverse
 
 from ..groups.models import Group
@@ -40,9 +41,47 @@ class Service(CreatedAtModel, UpdatableModel, PublicableModel, DeactivableModel)
     def __str__(self):
         return '{}:{}'.format(self.name, self.service_url)
 
-    def get_absolute_rest_url(self):
+    def get_relative_rest_url(self):
         return reverse("django_sso_app_service:rest-detail", args=[self.pk])
 
+    def subscribe(self, profile, update_rev=False):
+        updated = False
+        subscription, created = Subscription.objects.get_or_create(profile=profile, service=self)
+
+        if created:
+            logger.info('Profile "{}" subscription created "{}"'.format(profile, self))
+        else:
+            logger.info('Profile "{}" already subscribed "{}"'.format(profile, self))
+
+        if subscription.is_unsubscribed:
+            subscription.unsubscribed_at = None
+            subscription.save()
+            updated = True
+
+        if update_rev:
+            profile.update_rev(commit=True)
+
+        return subscription, created or updated
+
+    def unsubscribe(self, profile, update_rev=False):
+        updated = False
+        subscription, created = Subscription.objects.get_or_create(profile=profile, service=self)
+
+        if created:
+            logger.info('Profile "{}" subscription created "{}"'.format(profile, self))
+        else:
+            logger.info('Profile "{}" already subscribed "{}"'.format(profile, self))
+
+        if subscription.is_subscribed:
+            subscription.unsubscribed_at = timezone.now()
+            subscription.save()
+            updated = True
+
+        if update_rev:
+            profile.update_rev(commit=True)
+
+        return subscription, created or updated
+
 
 class TOS(CreatedAtModel, UpdatableModel, DeactivableModel):
     """
@@ -100,5 +139,5 @@ class Subscription(CreatedAtModel, UpdatableModel, DeactivableModel, PublicableM
     def __str__(self):
         return '{}@{}'.format(self.profile, self.service.service_url)
 
-    def get_absolute_rest_url(self):
+    def get_relative_rest_url(self):
         return reverse("django_sso_app_service:rest-subscription-detail", args=[self.pk])
