@@ -55,7 +55,7 @@ class DjangoSsoAppUserModelMixin(object):
 
     @property
     def password_has_been_hardened(self):
-        has_password = getattr(self, '__dssoa__old_password', self.password) not in [None, '']
+        has_password = getattr(self, '__dssoa__old_password', self.password) not in (None, '')
 
         try:
             if has_password:
