@@ -4,10 +4,9 @@ from django.core.exceptions import ObjectDoesNotExist
 from django.contrib.auth import get_user_model
 from django.contrib.auth.backends import ModelBackend
 
-from ...utils import set_session_key
 from ...apps.profiles.models import Profile
-from ...apps.users.utils import add_user_to_default_groups
-from ...apps.api_gateway.functions import get_apigateway_sso_id
+from ...apps.groups.utils import set_default_user_groups, set_default_profile_groups
+from ... import app_settings
 
 logger = logging.getLogger('django_sso_app.core.authentication.backends')
 User = get_user_model()
@@ -15,39 +14,35 @@ User = get_user_model()
 
 class DjangoSsoAppApiGatewayBackendAuthenticationBackend(ModelBackend):
     """
-    Authenticates by request CONSUMER_USERNAME header
+    Authenticates by request CONSUMER_CUSTOM_ID header
     """
 
     backend_path = 'django_sso_app.core.authentication.backends.DjangoSsoAppApiGatewayAuthenticationBackend'
 
-    def backend_authenticate(self, request, consumer_username, encoded_jwt, decoded_jwt):
-        logger.info('BACKEND authenticating by apigateway consumer {}'.format(consumer_username))
+    def backend_authenticate(self, request, consumer_custom_id, encoded_jwt, decoded_jwt):
+        logger.info('BACKEND authenticating by apigateway consumer {}'.format(consumer_custom_id))
 
-        if consumer_username is None:
-            logger.debug('consumer_username not set, skipping authentication')
+        if consumer_custom_id is None:
+            logger.debug('consumer_custom_id not set, skipping authentication')
 
             return
 
         try:
-            sso_id = get_apigateway_sso_id(consumer_username)
+            sso_id = consumer_custom_id
             profile = Profile.objects.get(sso_id=sso_id)
             user = profile.user
 
         except ObjectDoesNotExist:
-            logger.debug('user with apigateway consumer username "{}" does not exists'.format(consumer_username))
+            logger.debug('user with apigateway consumer_custom_id "{}" does not exists'.format(consumer_custom_id))
 
             return
 
         else:
-            logger.debug('user with apigateway consumer username "{}" exists'.format(consumer_username))
+            logger.debug('user with apigateway consumer_custom_id "{}" exists'.format(consumer_custom_id))
 
             # allauth logic
             setattr(user, 'backend', self.backend_path)
 
-        add_user_to_default_groups(user)
-
-        set_session_key(request, '__dssoa__requesting_user', user)
-
         return user
 
 
@@ -73,13 +68,7 @@ class DjangoSsoAppJwtBackendAuthenticationBackend(ModelBackend):
         else:
             logger.debug('user with sso_id "{}" exists'.format(sso_id))
 
-            set_session_key(request, '__dssoa__requesting_user', user)
-
             # allauth logic
             setattr(user, 'backend', self.backend_path)
 
-        add_user_to_default_groups(user)
-
-        set_session_key(request, '__dssoa__requesting_user', user)
-
         return user
