@@ -13,9 +13,9 @@ class AbsoluteUrlSerializer(serializers.ModelSerializer):
 
     def get_absolute_rest_url(self, obj):
         if getattr(obj, 'pk', None) is not None:
-            get_absolute_rest_url = getattr(obj, 'get_absolute_rest_url', None)
+            get_absolute_rest_url = getattr(obj, 'get_relative_rest_url', None)
             if get_absolute_rest_url is None:
-                raise NotImplementedError('Model must provide "get_absolute_rest_url" method.')
+                raise NotImplementedError('Model must provide "get_relative_rest_url" method.')
             else:
                 request = self.context['request']
                 return request.build_absolute_uri(get_absolute_rest_url())
@@ -30,7 +30,7 @@ class UserRelatedSerializer(serializers.Serializer):
             profile = getattr(user, 'sso_app_profile', None)
             if profile is not None:
                 request = self.context['request']
-                reverse_url = profile.get_absolute_rest_url()
+                reverse_url = profile.get_relative_rest_url()
                 return request.build_absolute_uri(reverse_url)
 
 
